#!/bin/bash

set -e

# For normal booting, boot device file systems such as /cfcard and /var are typically
# only mounted if the system has booted from that same boot device. However, during
# a "netboot", these boot device file systems are not mounted unless the overriding
# variable "bootarg.init.nbmntcf" has been set to "true". The default behavior of keeping
# the file systems unmounted during netboot allows for them to be recreated by a "netboot
# and install" operation, either for first time bare metal installations or as part of a
# boot device recovery operation.

get_env()
{
	na_loader.sh printenv "$1" 2> /dev/null || true
}

get_kernel_cmdline_arg()
{
	local arg="$1"
	local karg
	for karg in $(cat /proc/cmdline); do
		if [ "${karg}" = "${arg}" ]; then
			# An exact match was found.  Return success:
			return 0
		fi
		if [ "${karg%%=*}" = "${arg%%=*}" ]; then
			# If everything before the (left most) equal sign matches, then
			# return the portion after the equal sign:
			echo "${karg#*=}"
			return 0
		fi
	done

	# no match was found, return failure:
	return 1
}

netboot()
{
	local imagestr=$(get_kernel_cmdline_arg "image")
	if echo "${imagestr}" | grep -q "fat:" 2> /dev/null; then
		return 1
	fi
	return 0
}

if netboot; then
	if get_env bootarg.init.nbmntcf | grep -q -i "true"; then
		touch /run/mntcf
	fi
else
	touch /run/mntcf
fi

exit 0
